==> leechcraft-0.4.65.tar.bz2: leechcraft-0.4.65/src/plugins/newlife/leechcraft_newlife_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>FeedsSettingsImportPage</name>
    <message>
        <location filename="feedssettingsimportpage.ui" line="22"/>
        <source>Location:</source>
        <translation>Место:</translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="34"/>
        <source>Browse...</source>
        <translation>Обзор...</translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="45"/>
        <source>Import %1 settings as well</source>
        <extracomment>Application&apos;s name will be placed instead of %1, so please leave it where appropriate.</extracomment>
        <translation>Также импортировать настройки %1</translation>
    </message>
</context>
<context>
    <name>FirefoxProfileSelectPage</name>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.ui" line="24"/>
        <source>Select profile to import</source>
        <translation>Выберите профиль для импорта</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.ui" line="38"/>
        <source>Import history</source>
        <translation>Импорт истории</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.ui" line="45"/>
        <source>Import bookmarks </source>
        <translation>Импорт закладок</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.ui" line="52"/>
        <source>Import rss</source>
        <translation>Импорт RSS</translation>
    </message>
</context>
<context>
    <name>FirstPage</name>
    <message>
        <location filename="firstpage.ui" line="17"/>
        <source>Choose application</source>
        <translation>Выбор приложения</translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="20"/>
        <source>Choose appication that you want your data to be imported from</source>
        <translation>Выберите приложение, из которого будет произведен импорт</translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="28"/>
        <source>Source application:</source>
        <translation>Исходное приложение:</translation>
    </message>
</context>
<context>
    <name>ImportWizard</name>
    <message>
        <location filename="importwizard.ui" line="14"/>
        <source>Settings Import Wizard</source>
        <translation>Мастер импорта настроек</translation>
    </message>
    <message>
        <location filename="importwizard.ui" line="35"/>
        <source>Now please prepare for the import of data from the selected application.</source>
        <translation>Теперь, пожалуйста, приготовтесь к импорту данных из выбранного приложения.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::AkregatorImportPage</name>
    <message>
        <location filename="akregatorimportpage.cpp" line="40"/>
        <source>Akregator&apos;s feeds import</source>
        <translation>Импорт фидов из Akregator</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="41"/>
        <source>Select Akregator&apos;s feeds file and options</source>
        <translation>Выберите файл с фидами Akregator&apos;а и опции</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="103"/>
        <source>Select Akregator&apos;s OPML file</source>
        <translation>Выбор OPML-файла Akregator&apos;а</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="105"/>
        <source>OPML files (*.opml *.xml);;All files (*.*)</source>
        <translation>Файлы OPML (*.opml *.xml);;Все файлы (*.*)</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="112"/>
        <source>The file you&apos;ve selected is not a valid OPML file.</source>
        <translation>Файл, выбранный вами, не является валидным OPML-файлом.</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="155"/>
        <source>Akregator settings</source>
        <translation>Настройки Akregator</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="160"/>
        <source>Could not access or parse Akregator settings.</source>
        <translation>Невозможно получить доступ либо разобрать настройки Akregator.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::FirefoxImportPage</name>
    <message>
        <location filename="firefoximporter/firefoximportpage.cpp" line="39"/>
        <source>Firefox&apos;s data import</source>
        <translation>Импорт данных Firefox</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoximportpage.cpp" line="40"/>
        <location filename="firefoximporter/firefoximportpage.cpp" line="84"/>
        <source>Select Firefox&apos;s INI file</source>
        <translation>Выберите INI-файл Firefox</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoximportpage.cpp" line="86"/>
        <source>INI files (*.ini);;All files (*.*)</source>
        <translation>INI-файлы (*.ini);;Все файлы (*.*)</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoximportpage.cpp" line="93"/>
        <source>The file you&apos;ve selected is not a valid INI file.</source>
        <translation>Выбранный вами файл не является корректным INI-файлом.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::FirefoxProfileSelectPage</name>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.cpp" line="85"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.cpp" line="112"/>
        <source>Please close Firefox before importing.</source>
        <translation>Пожалуйста, закройте Firefox перед импортированием.</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.cpp" line="323"/>
        <source>OPML file for importing RSS cannot be created: %1</source>
        <translation>OPML-файл для импорта RSS не может быть создан: %1</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.cpp" line="344"/>
        <source>Firefox Import</source>
        <translation>Импорт из Firefox</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.cpp" line="345"/>
        <source>Could not open Firefox database: %1.</source>
        <translation>Невозможно открыть базу данных Firefox: %1.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::KTorrentImportPage</name>
    <message>
        <location filename="ktorrentimportpage.cpp" line="41"/>
        <source>KTorrent&apos;s torrents import</source>
        <translation>Импорт торрентов из KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="42"/>
        <source>Select KTorrent&apos;s torrents</source>
        <translation>Выберите торренты KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="85"/>
        <source>Select KTorrent&apos;s configuration file</source>
        <translation>Выберите конфигурационный файл KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="95"/>
        <source>Can&apos;t read KTorrent&apos;s configuration file</source>
        <translation>Невозможно прочитать конфигурационный файл KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="182"/>
        <source>KTorrent settings</source>
        <translation>Настройки KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="187"/>
        <source>Could not access or parse KTorrent settings.</source>
        <translation>Невозможно прочесть настройки KTorrent.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::LifereaImportPage</name>
    <message>
        <location filename="lifereaimportpage.cpp" line="40"/>
        <source>Liferea&apos;s feeds import</source>
        <translation>Импорт фидов из Liferea</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="41"/>
        <source>Select Liferea&apos;s base location and options</source>
        <translation>Выберите базовое положение директории Liferea и настройки</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="108"/>
        <source>Select Liferea&apos;s directory</source>
        <translation>Выбор директории Liferea</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="117"/>
        <source>The directory you&apos;ve selected is not Liferea&apos;s directory.</source>
        <translation>Выбранная вами директория не является директорией LIferea.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::Plugin</name>
    <message>
        <location filename="newlife.cpp" line="68"/>
        <source>The settings importer.</source>
        <translation>Импортер настроек.</translation>
    </message>
    <message>
        <location filename="newlife.cpp" line="37"/>
        <source>Import settings...</source>
        <translation>Импортировать настройки...</translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.75_rc20110524.tar.bz2: leechcraft-0.4.75_rc20110524/src/plugins/newlife/leechcraft_newlife_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>FeedsSettingsImportPage</name>
    <message>
        <location filename="feedssettingsimportpage.ui" line="22"/>
        <source>Location:</source>
        <translation>Место:</translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="34"/>
        <source>Browse...</source>
        <translation>Обзор...</translation>
    </message>
    <message>
        <location filename="feedssettingsimportpage.ui" line="45"/>
        <source>Import %1 settings as well</source>
        <extracomment>Application&apos;s name will be placed instead of %1, so please leave it where appropriate.</extracomment>
        <translation>Также импортировать параметры %1</translation>
    </message>
</context>
<context>
    <name>FirefoxProfileSelectPage</name>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.ui" line="24"/>
        <source>Select profile to import</source>
        <translation>Выберите профиль для импорта</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.ui" line="38"/>
        <source>Import history</source>
        <translation>Импорт истории</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.ui" line="45"/>
        <source>Import bookmarks </source>
        <translation>Импорт закладок</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.ui" line="52"/>
        <source>Import rss</source>
        <translation>Импорт RSS</translation>
    </message>
</context>
<context>
    <name>FirstPage</name>
    <message>
        <location filename="firstpage.ui" line="17"/>
        <source>Choose application</source>
        <translation>Выбор приложения</translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="20"/>
        <source>Choose appication that you want your data to be imported from</source>
        <translation>Выберите приложение, из которого будет произведён импорт</translation>
    </message>
    <message>
        <location filename="firstpage.ui" line="28"/>
        <source>Source application:</source>
        <translation>Исходное приложение:</translation>
    </message>
</context>
<context>
    <name>ImportWizard</name>
    <message>
        <location filename="importwizard.ui" line="14"/>
        <source>Settings Import Wizard</source>
        <translation>Мастер импорта параметров</translation>
    </message>
    <message>
        <location filename="importwizard.ui" line="35"/>
        <source>Now please prepare for the import of data from the selected application.</source>
        <translation>Теперь, пожалуйста, приготовьтесь к импорту данных из выбранного приложения.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::AkregatorImportPage</name>
    <message>
        <location filename="akregatorimportpage.cpp" line="40"/>
        <source>Akregator&apos;s feeds import</source>
        <translation>Импорт лент из Akregator</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="41"/>
        <source>Select Akregator&apos;s feeds file and options</source>
        <translation>Выберите файл с лентами Akregator&apos;а и опции</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="103"/>
        <source>Select Akregator&apos;s OPML file</source>
        <translation>Выбор OPML-файла Akregator&apos;а</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="105"/>
        <source>OPML files (*.opml *.xml);;All files (*.*)</source>
        <translation>Файлы OPML (*.opml *.xml);;Все файлы (*.*)</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="112"/>
        <source>The file you&apos;ve selected is not a valid OPML file.</source>
        <translation>Файл, выбранный вами, не является корректным OPML-файлом.</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="155"/>
        <source>Akregator settings</source>
        <translation>Параметры Akregator</translation>
    </message>
    <message>
        <location filename="akregatorimportpage.cpp" line="160"/>
        <source>Could not access or parse Akregator settings.</source>
        <translation>Невозможно получить доступ либо разобрать параметры Akregator.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::FirefoxImportPage</name>
    <message>
        <location filename="firefoximporter/firefoximportpage.cpp" line="39"/>
        <source>Firefox&apos;s data import</source>
        <translation>Импорт данных Firefox</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoximportpage.cpp" line="40"/>
        <location filename="firefoximporter/firefoximportpage.cpp" line="84"/>
        <source>Select Firefox&apos;s INI file</source>
        <translation>Выберите INI-файл Firefox</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoximportpage.cpp" line="86"/>
        <source>INI files (*.ini);;All files (*.*)</source>
        <translation>INI-файлы (*.ini);;Все файлы (*.*)</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoximportpage.cpp" line="93"/>
        <source>The file you&apos;ve selected is not a valid INI file.</source>
        <translation>Выбранный вами файл не является корректным INI-файлом.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::FirefoxProfileSelectPage</name>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.cpp" line="85"/>
        <source>Default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.cpp" line="112"/>
        <source>Please close Firefox before importing.</source>
        <translation>Пожалуйста, закройте Firefox перед импортированием.</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.cpp" line="323"/>
        <source>OPML file for importing RSS cannot be created: %1</source>
        <translation>OPML-файл для импорта RSS не может быть создан: %1</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.cpp" line="344"/>
        <source>Firefox Import</source>
        <translation>Импорт из Firefox</translation>
    </message>
    <message>
        <location filename="firefoximporter/firefoxprofileselectpage.cpp" line="345"/>
        <source>Could not open Firefox database: %1.</source>
        <translation>Невозможно открыть базу данных Firefox: %1.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::KTorrentImportPage</name>
    <message>
        <location filename="ktorrentimportpage.cpp" line="41"/>
        <source>KTorrent&apos;s torrents import</source>
        <translation>Импорт торрентов из KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="42"/>
        <source>Select KTorrent&apos;s torrents</source>
        <translation>Выберите торренты KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="85"/>
        <source>Select KTorrent&apos;s configuration file</source>
        <translation>Выберите конфигурационный файл KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="95"/>
        <source>Can&apos;t read KTorrent&apos;s configuration file</source>
        <translation>Невозможно прочитать конфигурационный файл KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="182"/>
        <source>KTorrent settings</source>
        <translation>Параметры KTorrent</translation>
    </message>
    <message>
        <location filename="ktorrentimportpage.cpp" line="187"/>
        <source>Could not access or parse KTorrent settings.</source>
        <translation>Невозможно прочесть параметры KTorrent.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::LifereaImportPage</name>
    <message>
        <location filename="lifereaimportpage.cpp" line="40"/>
        <source>Liferea&apos;s feeds import</source>
        <translation>Импорт лент из Liferea</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="41"/>
        <source>Select Liferea&apos;s base location and options</source>
        <translation>Выберите базовое положение каталога Liferea и параметры</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="108"/>
        <source>Select Liferea&apos;s directory</source>
        <translation>Выбор каталога Liferea</translation>
    </message>
    <message>
        <location filename="lifereaimportpage.cpp" line="117"/>
        <source>The directory you&apos;ve selected is not Liferea&apos;s directory.</source>
        <translation>Выбранный вами каталог не является каталогом LIferea.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::NewLife::Plugin</name>
    <message>
        <location filename="newlife.cpp" line="68"/>
        <source>The settings importer.</source>
        <translation>Импортёр параметров.</translation>
    </message>
    <message>
        <location filename="newlife.cpp" line="37"/>
        <source>Import settings...</source>
        <translation>Импортировать параметры...</translation>
    </message>
</context>
</TS>
